==> haskell-hasql-notifications-0.2.0.5-77-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-notifications.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-notifications
version:              0.2.0.5
visibility:           public
id:                   hasql-notifications-0.2.0.5-H6zCtEPhu8i7028veify09
key:                  hasql-notifications-0.2.0.5-H6zCtEPhu8i7028veify09
license:              BSD-3-Clause
copyright:            2020 Diogo Biazus
maintainer:           diogo@biazus.ca
author:               Diogo Biazus
homepage:             https://github.com/diogob/hasql-notifications
synopsis:             LISTEN/NOTIFY support for Hasql
description:
    Use PostgreSQL Asynchronous notification support with your Hasql Types.

category:             Hasql, Database, PostgreSQL
abi:                  0ea4d8126d133b07aedcf9aa8094ec29
exposed:              True
exposed-modules:      Hasql.Notifications
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hasql-notifications-0.2.0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hasql-notifications-0.2.0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hasql-notifications-0.2.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-notifications
hs-libraries:         HShasql-notifications-0.2.0.5-H6zCtEPhu8i7028veify09
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    hasql-1.5.0.5-Eu0rOxyXR5UB1q7HEFqUst
    hasql-pool-0.5.2.2-48rTdmabZxY2otqnVv0ulg
    postgresql-libpq-0.9.5.0-6Abcvnlrbx38D8lE6uFyjU text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hasql-notifications/html/hasql-notifications.haddock

haddock-html:         /usr/share/doc/haskell-hasql-notifications/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-notifications-0.2.0.5-78-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-notifications.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-notifications
version:              0.2.0.5
visibility:           public
id:                   hasql-notifications-0.2.0.5-ImAloH6wIIJ2e060p1iCfx
key:                  hasql-notifications-0.2.0.5-ImAloH6wIIJ2e060p1iCfx
license:              BSD-3-Clause
copyright:            2020 Diogo Biazus
maintainer:           diogo@biazus.ca
author:               Diogo Biazus
homepage:             https://github.com/diogob/hasql-notifications
synopsis:             LISTEN/NOTIFY support for Hasql
description:
    Use PostgreSQL Asynchronous notification support with your Hasql Types.

category:             Hasql, Database, PostgreSQL
abi:                  7ba6d7fcab3f043408cc3b51a14ab861
exposed:              True
exposed-modules:      Hasql.Notifications
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hasql-notifications-0.2.0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hasql-notifications-0.2.0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hasql-notifications-0.2.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-notifications
hs-libraries:         HShasql-notifications-0.2.0.5-ImAloH6wIIJ2e060p1iCfx
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    hasql-1.5.0.5-6xgX9lF7ywC8oNh7M9UgUa
    hasql-pool-0.5.2.2-1W6vsz1ITKZ3Fmd1tTYJcw
    postgresql-libpq-0.9.5.0-6Abcvnlrbx38D8lE6uFyjU text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hasql-notifications/html/hasql-notifications.haddock

haddock-html:         /usr/share/doc/haskell-hasql-notifications/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
